Yamlidator
==========

:Abstract: An Yaml/Json validator with a schema registry
:Author: Jaakko Kantojärvi <jaakko.kantojarvi@aalto.fi>

Yamlidator is a validator package, which provides a schema registry, a validator engine, a versioned yaml document and user friendly error rendering.
It is developed as part of apluslms-roman_.

.. _apluslms-roman: https://github.com/apluslms/roman
